@@ -16,25 +16,35 @@ def rules_list(request, template_name='robots/rule_list.html',
     """
     scheme = request.is_secure() and 'https' or 'http'
     current_site = Site.objects.get_current()
-    if settings.SITEMAP_URL:
-        sitemap_url = settings.SITEMAP_URL
-    else:
+
+    sitemap_url = settings.SITEMAP_URL
+    sitemap_urls = settings.SITEMAP_URLS
+
+    if not sitemap_urls and settings.USE_SITEMAP:
+        sitemap_url = None
+
         try:
             sitemap_url = reverse('django.contrib.sitemaps.views.index')
         except NoReverseMatch:
             try:
                 sitemap_url = reverse('django.contrib.sitemaps.views.sitemap')
             except NoReverseMatch:
-                sitemap_url = None
-    if sitemap_url is not None and settings.USE_SITEMAP:
-        sitemap_url = "%s://%s%s" % (scheme, current_site.domain, sitemap_url)
+                pass
+
+        if sitemap_url is not None:
+            sitemap_url = "%s://%s%s" % (scheme, current_site.domain, sitemap_url)
+            sitemap_urls.append(sitemap_url)
+
     rules = Rule.objects.filter(sites=current_site)
-    if not rules.count() and sitemap_url is None:
+
+    if not rules.count() and not sitemap_urls:
         status_code = 404
+
     t = loader.get_template(template_name)
     c = RequestContext(request, {
         'rules': rules,
-        'sitemap_url': sitemap_url,
+        'sitemap_url': sitemap_url, # for old templates
+        'sitemap_urls': sitemap_urls,
     })
     return HttpResponse(t.render(c), status=status_code, mimetype=mimetype)
 
